Learn R Programming

theftdlc (version 0.2.1)

get_rescale_vals: Calculate central tendency and spread values for all numeric columns in a dataset

Description

Calculate central tendency and spread values for all numeric columns in a dataset

Usage

get_rescale_vals(data)

Value

list of central tendency and spread values

Arguments

data

data.frame containing data to normalise

Author

Trent Henderson