find_good_features: Helper function to find features in both train and test set that are "good"
Description
Helper function to find features in both train and test set that are "good"
Usage
find_good_features(data, x)
Value
character vector of "good" feature names
Arguments
- data
list of "Train" and "Test" data
- x
integer denoting the resample index to operate on