Fit classification model and compute key metrics
fit_models(data, iter_data, row_id, is_null_run = FALSE, classifier)data.frame of classification results
list containing train and test sets
data.frame containing the values to iterate over for seed and either feature name or set name
integer denoting the row ID for iter_data to filter to
Boolean whether the calculation is for a null model. Defaults to FALSE
function specifying the classifier to fit. Should be a function with 2 arguments: formula and data. Please note that tsfeature_classifier z-scores data prior to modelling using the train set's information so disabling default scaling if your function uses it is recommended.
Trent Henderson